@@ -24,21 +24,21 @@ PNACL_NEWLIB_TOOLCHAIN = {
 }
 
 NACL32_NEWLIB_TOOLCHAIN = {
-    'CC':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/i686-nacl-gcc',
-    'CXX':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/i686-nacl-g++',
-    'AR':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/i686-nacl-ar',
-    'LINK':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/i686-nacl-g++',
-    'LD':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/i686-nacl-ld',
-    'RANLIB':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/i686-nacl-ranlib',
+    'CC':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/i686-nacl-gcc',
+    'CXX':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/i686-nacl-g++',
+    'AR':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/i686-nacl-ar',
+    'LINK':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/i686-nacl-g++',
+    'LD':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/i686-nacl-ld',
+    'RANLIB':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/i686-nacl-ranlib',
 }
 
 NACL64_NEWLIB_TOOLCHAIN = {
-    'CC':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/x86_64-nacl-gcc',
-    'CXX':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/x86_64-nacl-g++',
-    'AR':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/x86_64-nacl-ar',
-    'LINK':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/x86_64-nacl-g++',
-    'LD':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/x86_64-nacl-ld',
-    'RANLIB':'/opt/nacl_sdk/pepper_18/toolchain/*_x86_newlib/bin/x86_64-nacl-ranlib',
+    'CC':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/x86_64-nacl-gcc',
+    'CXX':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/x86_64-nacl-g++',
+    'AR':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/x86_64-nacl-ar',
+    'LINK':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/x86_64-nacl-g++',
+    'LD':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/x86_64-nacl-ld',
+    'RANLIB':'/opt/nacl_sdk/pepper_21/toolchain/*_x86_newlib/bin/x86_64-nacl-ranlib',
 }
 
 PNACL_OPTIONS = {
@@ -283,6 +283,26 @@ CLANG64_STATIC_CODE_COVERAGE_LIB = {
   'type':'staticlib'
 }
 
+CLANG32_STATIC_RELEASE_LIB =  {
+  'description':'builds a clang 32 bit static debug library',
+  'toolchain':CLANG_TOOLCHAIN,
+  'options':[BASIC_OPTIONS,
+             CLANG32_OPTIONS,
+             CLANG_RELEASE_OPTIONS
+            ],
+  'type':'staticlib'
+}
+
+CLANG64_STATIC_RELEASE_LIB = {
+  'description':'builds a clang 64 bit static debug library',
+  'toolchain':CLANG_TOOLCHAIN,
+  'options':[BASIC_OPTIONS,
+             CLANG64_OPTIONS,
+             CLANG_RELEASE_OPTIONS
+            ],
+  'type':'staticlib'
+}
+
 #################
 #  PREDEFINED BUILDS - IOS
 #################
